/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Polkit1AuthAgent.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "polkit1authagentadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Polkit1AuthAgentAdaptor
 */

Polkit1AuthAgentAdaptor::Polkit1AuthAgentAdaptor(PolicyKitListener *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Polkit1AuthAgentAdaptor::~Polkit1AuthAgentAdaptor()
{
    // destructor
}

void Polkit1AuthAgentAdaptor::setActivationTokenForAction(const QString &action, const QString &token)
{
    // handle method call org.kde.Polkit1AuthAgent.setActivationTokenForAction
    parent()->setActivationTokenForAction(action, token);
}

void Polkit1AuthAgentAdaptor::setWIdForAction(const QString &in0, qulonglong in1)
{
    // handle method call org.kde.Polkit1AuthAgent.setWIdForAction
    parent()->setWIdForAction(in0, in1);
}

void Polkit1AuthAgentAdaptor::setWindowHandleForAction(const QString &action, const QString &handle)
{
    // handle method call org.kde.Polkit1AuthAgent.setWindowHandleForAction
    parent()->setWindowHandleForAction(action, handle);
}


#include "moc_polkit1authagentadaptor.cpp"
