/****************************************************************************
** Meta object code from reading C++ file 'policykitlistener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../polkit-kde-agent-1-6.7.4/policykitlistener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'policykitlistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PolicyKitListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto PolicyKitListener::qt_create_metaobjectdata<qt_meta_tag_ZN17PolicyKitListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PolicyKitListener",
        "D-Bus Interface",
        "org.kde.Polkit1AuthAgent",
        "initiateAuthentication",
        "",
        "actionId",
        "message",
        "iconName",
        "PolkitQt1::Details",
        "details",
        "cookie",
        "PolkitQt1::Identity::List",
        "identities",
        "PolkitQt1::Agent::AsyncResult*",
        "result",
        "initiateAuthenticationFinish",
        "cancelAuthentication",
        "tryAgain",
        "finishObtainPrivilege",
        "request",
        "echo",
        "completed",
        "gainedAuthorization",
        "showError",
        "text",
        "showInfo",
        "setWIdForAction",
        "action",
        "wID",
        "setWindowHandleForAction",
        "handle",
        "setActivationTokenForAction",
        "token",
        "dialogAccepted",
        "dialogCanceled",
        "userSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'initiateAuthentication'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const PolkitQt1::Details &, const QString &, const PolkitQt1::Identity::List &, PolkitQt1::Agent::AsyncResult *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'initiateAuthenticationFinish'
        QtMocHelpers::SlotData<bool()>(15, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'cancelAuthentication'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tryAgain'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finishObtainPrivilege'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'request'
        QtMocHelpers::SlotData<void(const QString &, bool)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'completed'
        QtMocHelpers::SlotData<void(bool)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'showError'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'showInfo'
        QtMocHelpers::SlotData<void(const QString &)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'setWIdForAction'
        QtMocHelpers::SlotData<void(const QString &, qulonglong)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::ULongLong, 28 },
        }}),
        // Slot 'setWindowHandleForAction'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'setActivationTokenForAction'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'dialogAccepted'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dialogCanceled'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'userSelected'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PolicyKitListener, qt_meta_tag_ZN17PolicyKitListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PolicyKitListener::staticMetaObject = { {
    QMetaObject::SuperData::link<Listener::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PolicyKitListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PolicyKitListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PolicyKitListenerE_t>.metaTypes,
    nullptr
} };

void PolicyKitListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PolicyKitListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initiateAuthentication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PolkitQt1::Details>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<PolkitQt1::Identity::List>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<PolkitQt1::Agent::AsyncResult*>>(_a[7]))); break;
        case 1: { bool _r = _t->initiateAuthenticationFinish();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->cancelAuthentication(); break;
        case 3: _t->tryAgain(); break;
        case 4: _t->finishObtainPrivilege(); break;
        case 5: _t->request((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->completed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->showInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setWIdForAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 10: _t->setWindowHandleForAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->setActivationTokenForAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->dialogAccepted(); break;
        case 13: _t->dialogCanceled(); break;
        case 14: _t->userSelected(); break;
        default: ;
        }
    }
}

const QMetaObject *PolicyKitListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PolicyKitListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PolicyKitListenerE_t>.strings))
        return static_cast<void*>(this);
    return Listener::qt_metacast(_clname);
}

int PolicyKitListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Listener::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
