/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Polkit1AuthAgent.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POLKIT1AUTHAGENTADAPTOR_H
#define POLKIT1AUTHAGENTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "policykitlistener.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Polkit1AuthAgent
 */
class Polkit1AuthAgentAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Polkit1AuthAgent")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Polkit1AuthAgent\">\n"
"    <method name=\"setWIdForAction\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"setWindowHandleForAction\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"action\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"handle\"/>\n"
"    </method>\n"
"    <method name=\"setActivationTokenForAction\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"action\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"token\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Polkit1AuthAgentAdaptor(PolicyKitListener *parent);
    ~Polkit1AuthAgentAdaptor() override;

    inline PolicyKitListener *parent() const
    { return static_cast<PolicyKitListener *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void setActivationTokenForAction(const QString &action, const QString &token);
    void setWIdForAction(const QString &in0, qulonglong in1);
    void setWindowHandleForAction(const QString &action, const QString &handle);
Q_SIGNALS: // SIGNALS
};

#endif
